@@ -3,7 +3,7 @@ from enum import EnumMeta
 from graphql import GraphQLEnumType, GraphQLEnumValue
 
 from .exceptions import NotAnEnum
-from .type_converter import REGISTRY
+from .type_registry import register_type
 
 
 def _process_enum(cls, name=None, description=None):
@@ -13,16 +13,16 @@ def _process_enum(cls, name=None, description=None):
     if not name:
         name = cls.__name__
 
-    REGISTRY[name] = cls
-
     description = description or cls.__doc__
 
-    cls.graphql_type = GraphQLEnumType(
+    graphql_type = GraphQLEnumType(
         name=name,
         values=[(item.name, GraphQLEnumValue(item.value)) for item in cls],
         description=description,
     )
 
+    register_type(cls, graphql_type)
+
     return cls
 
 
